pub struct MockPreviewInvoiceApi {
PreviewInvoiceApi_expectations: MockPreviewInvoiceApi_PreviewInvoiceApi,
}Fields
PreviewInvoiceApi_expectations: MockPreviewInvoiceApi_PreviewInvoiceApiImplementations
Sourceimpl MockPreviewInvoiceApi
impl MockPreviewInvoiceApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockPreviewInvoiceApi
impl MockPreviewInvoiceApi
Sourcepub fn expect_preview_organization_subscription_plan_change_tax(
&mut self,
) -> &mut Expectation
pub fn expect_preview_organization_subscription_plan_change_tax( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the preview_organization_subscription_plan_change_tax method
Sourcepub fn expect_preview_organization_subscription_purchase_tax(
&mut self,
) -> &mut Expectation
pub fn expect_preview_organization_subscription_purchase_tax( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the preview_organization_subscription_purchase_tax method
Sourcepub fn expect_preview_organization_subscription_update_tax(
&mut self,
) -> &mut Expectation
pub fn expect_preview_organization_subscription_update_tax( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the preview_organization_subscription_update_tax method
Create an Expectation for mocking the preview_premium_subscription_purchase_tax method
Create an Expectation for mocking the preview_premium_upgrade_proration method